#[non_exhaustive]pub enum DelayParameters {
Timeout {
timeout: Duration,
},
}Available on crate feature
api and crate feature unstable-msc4140 and (crate features client-api-c or client-api-s) and (crate features client or server) only.Expand description
The query parameters for a delayed event request.
It contains the timeout configuration for a delayed event.
This enum is no longer used except by deprecated endpoints.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Timeout
Sending a delayed event with a timeout. The response will contain a (server
generated) delay_id instead of an event_id.