#[non_exhaustive]pub struct Request {
pub room_id: OwnedRoomId,
pub event_type: TimelineEventType,
pub txn_id: OwnedTransactionId,
pub delay: Duration,
pub state_key: Option<String>,
pub content: Raw<AnyTimelineEventContent>,
}api and crate feature unstable-msc4140 and (crate features client-api-c or client-api-s) and (crate features client or server) only.Expand description
Request type for the send_delayed_event
endpoint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.room_id: OwnedRoomIdThe room to send the event to.
event_type: TimelineEventTypeThe type of event to send.
txn_id: OwnedTransactionIdThe transaction ID for this event.
Clients should generate a unique ID across requests within the same session. A session is identified by an access token, and persists when the access token is refreshed.
It will be used by the server to ensure idempotency of requests.
delay: DurationThe duration that the server should wait before sending this event
state_key: Option<String>The State Key if the event is a state event, nothing otherwise
content: Raw<AnyTimelineEventContent>The event content to send.
Implementations
Sourceimpl Request
impl Request
Sourcepub fn new(
room_id: OwnedRoomId,
txn_id: OwnedTransactionId,
delay: Duration,
state_key: Option<String>,
content: &AnyTimelineEventContent,
) -> Result<Request, Error>
pub fn new( room_id: OwnedRoomId, txn_id: OwnedTransactionId, delay: Duration, state_key: Option<String>, content: &AnyTimelineEventContent, ) -> Result<Request, Error>
Creates a new Request with the given room id, transaction id, delay_parameters and
event content.
Errors
Since Request stores the request body in serialized form, this function can fail if
Ts ::serde::Serialize implementation can fail.
Sourcepub fn new_raw(
event_type: TimelineEventType,
room_id: OwnedRoomId,
txn_id: OwnedTransactionId,
delay: Duration,
state_key: Option<String>,
content: Raw<AnyTimelineEventContent>,
) -> Result<Request, Error>
pub fn new_raw( event_type: TimelineEventType, room_id: OwnedRoomId, txn_id: OwnedTransactionId, delay: Duration, state_key: Option<String>, content: Raw<AnyTimelineEventContent>, ) -> Result<Request, Error>
Creates a new Request with the given room id, transaction id, event type,
delay_parameters and raw event content.