AccountManagementAction

Enum AccountManagementAction 

#[non_exhaustive]
pub enum AccountManagementAction { Profile, UnstableSessionsList, DevicesList, UnstableSessionView, DeviceView, UnstableSessionEnd, DeviceDelete, AccountDeactivate, CrossSigningReset, }
Available on crate feature api and (crate features client or server) only.
The action that the user wishes to do at the account management URL.

This enum supports both the values that were first specified in MSC4191 and the values that replaced them in the Matrix specification, for backwards compatibility with unstable implementations. The variants that were replaced all use an Unstable prefix.

This type can hold an arbitrary string. To build this with a custom value, convert it from a string with ::from() / .into(). To check for values that are not available as a documented variant here, use its string representation, obtained through .as_str().

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Profile

The user wishes to view or edit their profile (name, avatar, contact details).



UnstableSessionsList

The unstable version of AccountManagementAction::DevicesList.

This uses the org.matrix.sessions_list string that was first specified in MSC4191 before being replaced by org.matrix.devices_list.



DevicesList

The user wishes to view a list of their devices.



UnstableSessionView

The unstable version of AccountManagementAction::DeviceView.

This uses the org.matrix.session_view string that was first specified in MSC4191 before being replaced by org.matrix.device_view.



DeviceView

The user wishes to view the details of a specific device.



UnstableSessionEnd

The unstable version of AccountManagementAction::DeviceDelete.

This uses the org.matrix.session_end string that was first specified in MSC4191 before being replaced by org.matrix.device_delete.



DeviceDelete

The user wishes to delete/log out a specific device.



AccountDeactivate

The user wishes to deactivate their account.



CrossSigningReset

The user wishes to reset their cross-signing keys.

Servers should use this action in the URL of the m.oauth UIA type.

Implementations



impl AccountManagementAction

pub fn as_str(&self) -> &str

Creates a string slice from this AccountManagementAction.