#[non_exhaustive]pub enum AccountManagementActionData<'a> {
Profile,
DevicesList,
DeviceView(DeviceViewData<'a>),
DeviceDelete(DeviceDeleteData<'a>),
AccountDeactivate,
CrossSigningReset,
}Available on crate feature
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Expand description
The action that the user wishes to do at the account management URL with its associated data.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Profile
The user wishes to view or edit their profile (name, avatar, contact details).
DevicesList
The user wishes to view a list of their devices.
DeviceView(DeviceViewData<'a>)
The user wishes to view the details of a specific device.
DeviceDelete(DeviceDeleteData<'a>)
The user wishes to delete/log out a specific device.
AccountDeactivate
The user wishes to deactivate their account.
CrossSigningReset
The user wishes to reset their cross-signing keys.