Struct ForgetForcedUponLeaveCapability
#[non_exhaustive]pub struct ForgetForcedUponLeaveCapability {
pub enabled: bool,
}Available on crate feature
api and (crate features client or server) only.Expand description
Information about the m.forget_forced_upon_leave capability.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: boolWhether the server will automatically forget any room that the user leaves.
This behavior applies irrespective of whether the user has left the room on their own or has been kicked or banned from the room by another user.
Implementations
impl ForgetForcedUponLeaveCapability
impl ForgetForcedUponLeaveCapability
pub fn new(enabled: bool) -> ForgetForcedUponLeaveCapability
pub fn new(enabled: bool) -> ForgetForcedUponLeaveCapability
Creates a new ForgetForcedUponLeaveCapability with the given enabled flag.
pub fn is_default(&self) -> bool
pub fn is_default(&self) -> bool
Returns whether all fields have their default value.