#[non_exhaustive]pub struct UnknownTokenErrorData {
pub soft_logout: bool,
}Available on crate feature
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Expand description
Data for the M_UNKNOWN_TOKEN ErrorKind.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.soft_logout: boolIf this is true, the client is in a “soft logout” state, i.e. the server requires
re-authentication but the session is not invalidated. The client can acquire a new
access token by specifying the device ID it is already using to the login API.
Implementations
Sourceimpl UnknownTokenErrorData
impl UnknownTokenErrorData
Sourcepub fn new() -> UnknownTokenErrorData
pub fn new() -> UnknownTokenErrorData
Construct a new UnknownTokenErrorData with soft_logout set to false.