pub enum UrlFilter {
EventsWithUrl,
EventsWithoutUrl,
}Available on crate feature
api and (crate features client or server) only.Expand description
Options for filtering based on the presence of a URL.
Variants
EventsWithUrl
Includes only events with a url key in their content.
EventsWithoutUrl
Excludes events with a url key in their content.