Struct FilterDefinition
#[non_exhaustive]pub struct FilterDefinition {
pub event_fields: Option<Vec<String>>,
pub event_format: EventFormat,
pub presence: Filter,
pub account_data: Filter,
pub room: RoomFilter,
}api and (crate features client or server) only.Expand description
A filter definition
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.event_fields: Option<Vec<String>>List of event fields to include.
If this list is absent then all fields are included. The entries may include ‘.’ characters to indicate sub-fields. So [‘content.body’] will include the ‘body’ field of the ‘content’ object. A literal ‘.’ or ’' character in a field name may be escaped using a ’'. A server may include more fields than were requested.
event_format: EventFormatThe format to use for events.
‘client’ will return the events in a format suitable for clients. ‘federation’ will return the raw event as received over federation. The default is ‘client’.
presence: FilterThe presence updates to include.
account_data: FilterThe user account data that isn’t associated with rooms to include.
room: RoomFilterFilters to be applied to room data.
Implementations
impl FilterDefinition
impl FilterDefinition
pub fn empty() -> FilterDefinition
pub fn empty() -> FilterDefinition
Creates an empty FilterDefinition.
You can also use the Default implementation.
pub fn ignore_all() -> FilterDefinition
pub fn ignore_all() -> FilterDefinition
Creates a new FilterDefinition that can be used to ignore all events.
pub fn with_lazy_loading() -> FilterDefinition
pub fn with_lazy_loading() -> FilterDefinition
Creates a new FilterDefinition with room member lazy-loading enabled.
Redundant membership events are disabled.