Struct RoomFilter
#[non_exhaustive]pub struct RoomFilter {
pub include_leave: bool,
pub account_data: RoomEventFilter,
pub timeline: RoomEventFilter,
pub ephemeral: RoomEventFilter,
pub state: RoomEventFilter,
pub not_rooms: Vec<OwnedRoomId>,
pub rooms: Option<Vec<OwnedRoomId>>,
}api and (crate features client or server) only.Expand description
Filters to be applied to room data.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.include_leave: boolInclude rooms that the user has left in the sync.
Defaults to false.
account_data: RoomEventFilterThe per user account data to include for rooms.
timeline: RoomEventFilterThe message and state update events to include for rooms.
ephemeral: RoomEventFilterThe events that aren’t recorded in the room history, e.g. typing and receipts, to include for rooms.
state: RoomEventFilterThe state events to include for rooms.
not_rooms: Vec<OwnedRoomId>A list of room IDs to exclude.
If this list is absent then no rooms are excluded. A matching room will be excluded even if
it is listed in the ‘rooms’ filter. This filter is applied before the filters in
ephemeral, state, timeline or account_data.
rooms: Option<Vec<OwnedRoomId>>A list of room IDs to include.
If this list is absent then all rooms are included. This filter is applied before the
filters in ephemeral, state, timeline or account_data.
Implementations
impl RoomFilter
impl RoomFilter
pub fn empty() -> RoomFilter
pub fn empty() -> RoomFilter
Creates an empty RoomFilter.
You can also use the Default implementation.
pub fn ignore_all() -> RoomFilter
pub fn ignore_all() -> RoomFilter
Creates a new RoomFilter that can be used to ignore all room events (of any type).
pub fn with_lazy_loading() -> RoomFilter
pub fn with_lazy_loading() -> RoomFilter
Creates a new RoomFilter with room member lazy-loading enabled.
Redundant membership events are disabled.