#[non_exhaustive]pub struct Request {
pub server_name: OwnedServerName,
pub media_id: String,
pub allow_remote: bool,
pub timeout_ms: Duration,
pub allow_redirect: bool,
}Since Matrix 1.11, clients should use authenticated_media::get_content::v1::Request instead if the homeserver supports it.
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Expand description
Request type for the get_media_content endpoint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.server_name: OwnedServerNameSince Matrix 1.11, clients should use authenticated_media::get_content::v1::Request instead if the homeserver supports it.
The server name from the mxc:// URI (the authoritory component).
media_id: StringSince Matrix 1.11, clients should use authenticated_media::get_content::v1::Request instead if the homeserver supports it.
The media ID from the mxc:// URI (the path component).
allow_remote: boolSince Matrix 1.11, clients should use authenticated_media::get_content::v1::Request instead if the homeserver supports it.
Whether to fetch media deemed remote.
Used to prevent routing loops. Defaults to true.
timeout_ms: DurationSince Matrix 1.11, clients should use authenticated_media::get_content::v1::Request instead if the homeserver supports it.
The maximum duration that the client is willing to wait to start receiving data, in the case that the content has not yet been uploaded.
The default value is 20 seconds.
allow_redirect: boolSince Matrix 1.11, clients should use authenticated_media::get_content::v1::Request instead if the homeserver supports it.
Whether the server may return a 307 or 308 redirect response that points at the relevant media content.
Unless explicitly set to true, the server must return the media content itself.
Implementations