Struct UserProfile
pub struct UserProfile(/* private fields */);Available on crate feature
api and (crate features client or server) only.Expand description
All the profile information for a user.
Implementations
impl UserProfile
impl UserProfile
pub fn new() -> UserProfile
pub fn new() -> UserProfile
Creates a new empty UserProfile.
pub fn get_static<F>(
&self,
) -> Result<Option<<F as StaticProfileField>::Value>, Error>where
F: StaticProfileField,
pub fn get_static<F>(
&self,
) -> Result<Option<<F as StaticProfileField>::Value>, Error>where
F: StaticProfileField,
Returns the value of the given StaticProfileField.
Returns Ok(Some(_)) if the field is present and the value was deserialized
successfully, Ok(None) if the field is not set, or an error if deserialization of the
value failed.
pub fn merge(&mut self, profile_update: UserProfileUpdate)
Available on crate feature unstable-msc4262 only.
pub fn merge(&mut self, profile_update: UserProfileUpdate)
unstable-msc4262 only.Merges a profile that contains updates (such as from a sync response) with this profile.
This operation preserves omitted values and removes null values.