Struct UserProfileUpdate
pub struct UserProfileUpdate(/* private fields */);Available on crate feature
api and (crate features client or server) only.Expand description
An update to the profile information for a user.
This type is not supposed to be used directly, but merged into a
UserProfile.
Implementations
impl UserProfileUpdate
impl UserProfileUpdate
pub fn new() -> UserProfileUpdate
pub fn new() -> UserProfileUpdate
Creates a new empty UserProfileUpdate.
pub fn get_static<F>(
&self,
) -> Result<Option<<F as StaticProfileField>::Value>, Error>where
F: StaticProfileField,
pub fn get_static<F>(
&self,
) -> Result<Option<<F as StaticProfileField>::Value>, Error>where
F: StaticProfileField,
Returns the value of the given StaticProfileField.
Returns Ok(Some(_)) if the field is present and the value was deserialized
successfully, Ok(None) if the field is not set, or an error if deserialization of the
value failed.