Enum RtcTransport
#[non_exhaustive]pub enum RtcTransport {
LiveKit(LiveKitRtcTransport),
}api and (crate features client or server) and crate feature unstable-msc4143 only.Expand description
Information about a specific MatrixRTC transport.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
LiveKit(LiveKitRtcTransport)
unstable-msc4195 only.A LiveKit RTC transport.
Implementations
impl RtcTransport
impl RtcTransport
pub fn new(
transport_type: &str,
data: Map<String, Value>,
) -> Result<RtcTransport, Error>
pub fn new( transport_type: &str, data: Map<String, Value>, ) -> Result<RtcTransport, Error>
A constructor to create a custom RTC transport.
Prefer to use the public variants of RtcTransport where possible; this constructor is
meant to be used for unsupported transport types only and does not allow setting arbitrary
data for supported ones.
Errors
Returns an error if the transport_type is known and serialization of data to the
corresponding RtcTransport variant fails.
pub fn livekit(service_url: String) -> RtcTransport
Available on crate feature unstable-msc4195 only.
pub fn livekit(service_url: String) -> RtcTransport
unstable-msc4195 only.Creates a new RtcTransport::LiveKit.
pub fn transport_type(&self) -> &str
pub fn transport_type(&self) -> &str
Returns a reference to the transport type of this RTC transport.
pub fn data(&self) -> Cow<'_, Map<String, Value>>
pub fn data(&self) -> Cow<'_, Map<String, Value>>
Returns the associated data.
The returned JSON object won’t contain the type field, please use
.transport_type() to access that.
Prefer to use the public variants of RtcTransport where possible; this method is meant
to be used for custom transport types only.