Enum SsoRedirectAction
#[non_exhaustive]pub enum SsoRedirectAction {
Login,
Register,
}Available on crate feature
api and (crate features client or server) only.Expand description
Possible actions that a user wishes to take at the SSO redirect endpoints.
This type can hold an arbitrary string. To build this with a custom value, convert it from a
string with ::from() / .into(). To check for values that are not available as a
documented variant here, use its string representation, obtained through
.as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Login
The SSO redirect is for the purpose of signing an existing user in.
Register
The SSO redirect is for the purpose of registering a new user account.
Implementations
impl SsoRedirectAction
impl SsoRedirectAction