#[non_exhaustive]pub enum IdentityProviderBrand {
Apple,
Facebook,
GitHub,
GitLab,
Google,
Twitter,
}Available on crate feature
api and (crate features client or server) only.Expand description
An SSO login identity provider brand identifier.
The predefined ones can be found in the matrix-spec-proposals repo in a separate document.
This type can hold an arbitrary string. To build this with a custom value, convert it from a
string with ::from() / .into(). To check for values that are not available as a
documented variant here, use its string representation, obtained through
.as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Apple
The Apple brand.
The Facebook brand.
GitHub
The GitHub brand.
GitLab
The GitLab brand.
The Google brand.
The Twitter brand.
Implementations