Struct Response
#[non_exhaustive]pub struct Response {
pub event_or_content: Box<RawValue>,
}Expand description
Response type for the get_state_events_for_key endpoint, either the Raw AnyStateEvent
or AnyStateEventContent.
While it’s possible to access the raw value directly, it’s recommended you use the
provided helper methods to access it, and From to create it.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.event_or_content: Box<RawValue>The full event (content) of the state event.
Implementations
impl Response
impl Response
pub fn new(event_or_content: Box<RawValue>) -> Response
pub fn new(event_or_content: Box<RawValue>) -> Response
Creates a new Response with the given event (content).
pub fn into_event(self) -> Raw<AnyStateEvent>
pub fn into_event(self) -> Raw<AnyStateEvent>
Returns an unchecked Raw<AnyStateEvent>.
This method should only be used if you specified the format in the request to be
StateEventFormat::Event
pub fn into_content(self) -> Raw<AnyStateEventContent>
pub fn into_content(self) -> Raw<AnyStateEventContent>
Returns an unchecked Raw<AnyStateEventContent>.
This method should only be used if you did not specify the format in the request, or
set it to be StateEventFormat::Content
Since the inner type of the Raw does not implement Deserialize, you need to use
.deserialize_as_unchecked::<T>() or
.cast_ref_unchecked::<T>().deserialize_with_type() to deserialize it.