JetStream Rpc
Defines Rpc primitives for JetStream.
Of note is the Protocol trait which is meant to be used with the service attribute macro.
Modules
Structs
- Frame
- Framed
- A unified
StreamandSinkinterface to an underlying I/O object, using theEncoderandDecodertraits to encode and decode frames. - Tag