#[non_exhaustive]pub enum AuthType {
Password,
ReCaptcha,
EmailIdentity,
Msisdn,
Sso,
Dummy,
RegistrationToken,
Terms,
}Expand description
The type of an authentication stage.
This type can hold an arbitrary string. To build this with a custom value, convert it from a
string with ::from() / .into(). To check for values that are not available as a
documented variant here, use its string representation, obtained through
.as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Password
Password-based authentication (m.login.password).
ReCaptcha
Google ReCaptcha 2.0 authentication (m.login.recaptcha).
EmailIdentity
Email-based authentication (m.login.email.identity).
Msisdn
Phone number-based authentication (m.login.msisdn).
Sso
SSO-based authentication (m.login.sso).
Dummy
Dummy authentication (m.login.dummy).
RegistrationToken
Registration token-based authentication (m.login.registration_token).
Terms
Terms of service (m.login.terms).
This type is only valid during account registration.
Implementations