Struct PhoneNumberUserIdentifier
#[non_exhaustive]pub struct PhoneNumberUserIdentifier {
pub country: String,
pub phone: String,
}Available on crate feature
api and (crate features client or server) only.Expand description
Data for a phone number identifier as a separate country code and phone number.
The homeserver is responsible for canonicalizing this to the MSISDN format.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.country: StringThe country that the phone number is from.
This is a two-letter uppercase ISO-3166-1 alpha-2 country code.
phone: StringThe phone number.
Implementations
impl PhoneNumberUserIdentifier
impl PhoneNumberUserIdentifier
pub fn new(country: String, phone: String) -> PhoneNumberUserIdentifier
pub fn new(country: String, phone: String) -> PhoneNumberUserIdentifier
Construct a new PhoneNumberUserIdentifier with the given country code and phone number.