Enum RegistrationKind
#[non_exhaustive]pub enum RegistrationKind {
Guest,
User,
}Available on crate feature
api and (crate features client or server) only.Expand description
The kind of account being registered.
This type can hold an arbitrary string. To build this with a custom value, convert it from a
string with ::from() / .into(). To check for values that are not available as a
documented variant here, use its string representation, obtained through
.as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Guest
A guest account.
These accounts may have limited permissions and may not be supported by all servers.
User
A regular user account.
Implementations
impl RegistrationKind
impl RegistrationKind