#[non_exhaustive]pub enum DelayedEventStatus {
Scheduled,
Send,
Cancel,
Error,
}Available on crate feature
api and crate feature unstable-msc4140 and (crate features client-api-c or client-api-s) and (crate features client or server) only.Expand description
The status that a delayed event stored on the server can have.
This type can hold an arbitrary string. To build this with a custom value, convert it from a
string with ::from() / .into(). To check for values that are not available as a
documented variant here, use its string representation, obtained through
.as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Scheduled
The event is currently scheduled to be submitted at a later date. It may be restarted, sent or cancelled via the management endpoint.
Send
The event has been sent successfully.
Cancel
The event has been cancelled.
Error
The event has encountered an error when trying to send.
Implementations