#[non_exhaustive]pub struct AccountModerationCapability {
pub suspend: bool,
pub lock: bool,
}Available on crate feature
api and (crate features client-api-c or client-api-s) and (crate features client or server) only.Expand description
Information about the m.account_moderation capability.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.suspend: boolWhether the user can suspend a user via PUT /admin/suspend/{userId}.
lock: boolWhether the user can lock a user via PUT /admin/lock/{userId}.
Implementations
Sourceimpl AccountModerationCapability
impl AccountModerationCapability
Sourcepub fn new(suspend: bool, lock: bool) -> AccountModerationCapability
pub fn new(suspend: bool, lock: bool) -> AccountModerationCapability
Creates a new AccountModerationCapability with the given suspend and lock
capabilities.
Sourcepub fn is_default(&self) -> bool
pub fn is_default(&self) -> bool
Returns whether all fields have their default value.