#[non_exhaustive]pub struct CallProfileField {
pub call_joined_ts: Option<SecondsSinceUnixEpoch>,
}Available on crate feature
api and crate feature unstable-msc4426 and (crate features client-api-c or client-api-s) and (crate features client or server) only.Expand description
An indicator that the user is currently in a call, and optionally how long they’ve been in the call.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.call_joined_ts: Option<SecondsSinceUnixEpoch>The time that the user joined the call.
This allows users to see how long someone has been in a call.