Struct ResultGroupMapsByGroupingKey
#[non_exhaustive]pub struct ResultGroupMapsByGroupingKey(/* private fields */);api and (crate features client or server) only.Expand description
A map of GroupingKey to the associated ResultGroupMap.
This type is used to ensure that a supported ResultGroupMap always uses the appropriate
GroupingKey.
Implementations
impl ResultGroupMapsByGroupingKey
impl ResultGroupMapsByGroupingKey
pub fn new() -> ResultGroupMapsByGroupingKey
pub fn new() -> ResultGroupMapsByGroupingKey
Construct an empty ResultGroupMapsByGroupingKey.
pub fn insert(&mut self, map: ResultGroupMap) -> Option<ResultGroupMap>
pub fn insert(&mut self, map: ResultGroupMap) -> Option<ResultGroupMap>
Insert the given ResultGroupMap.
If a map with the same GroupingKey was already present, it is returned.
Methods from Deref<Target = BTreeMap<GroupingKey, ResultGroupMap>>
1.0.0 · Sourcepub fn get<Q>(&self, key: &Q) -> Option<&V>
Available on (crate features testing) and non-target_family=wasm and crate feature e2e-encryption only.
pub fn get<Q>(&self, key: &Q) -> Option<&V>
testing) and non-target_family=wasm and crate feature e2e-encryption only.Returns a reference to the value corresponding to the key.
The key may be any borrowed form of the map’s key type, but the ordering on the borrowed form must match the ordering on the key type.
Examples
use std::collections::BTreeMap;
let mut map = BTreeMap::new();
map.insert(1, "a");
assert_eq!(map.get(&1), Some(&"a"));
assert_eq!(map.get(&2), None);1.40.0 · Sourcepub fn get_key_value<Q>(&self, k: &Q) -> Option<(&K, &V)>
Available on (crate features testing) and non-target_family=wasm and crate feature e2e-encryption only.
pub fn get_key_value<Q>(&self, k: &Q) -> Option<(&K, &V)>
testing) and non-target_family=wasm and crate feature e2e-encryption only.Returns the key-value pair corresponding to the supplied key. This is potentially useful:
- for key types where non-identical keys can be considered equal;
- for getting the
&Kstored key value from a borrowed&Qlookup key; or - for getting a reference to a key with the same lifetime as the collection.
The supplied key may be any borrowed form of the map’s key type, but the ordering on the borrowed form must match the ordering on the key type.
Examples
use std::cmp::Ordering;
use std::collections::BTreeMap;
#[derive(Clone, Copy, Debug)]
struct S {
id: u32,
name: &'static str, // ignored by equality and ordering operations
}
impl PartialEq for S {
fn eq(&self, other: &S) -> bool {
self.id == other.id
}
}
impl Eq for S {}
impl PartialOrd for S {
fn partial_cmp(&self, other: &S) -> Option<Ordering> {
self.id.partial_cmp(&other.id)
}
}
impl Ord for S {
fn cmp(&self, other: &S) -> Ordering {
self.id.cmp(&other.id)
}
}
let j_a = S { id: 1, name: "Jessica" };
let j_b = S { id: 1, name: "Jess" };
let p = S { id: 2, name: "Paul" };
assert_eq!(j_a, j_b);
let mut map = BTreeMap::new();
map.insert(j_a, "Paris");
assert_eq!(map.get_key_value(&j_a), Some((&j_a, &"Paris")));
assert_eq!(map.get_key_value(&j_b), Some((&j_a, &"Paris"))); // the notable case
assert_eq!(map.get_key_value(&p), None);1.66.0 · Sourcepub fn first_key_value(&self) -> Option<(&K, &V)>where
K: Ord,
Available on (crate features testing) and non-target_family=wasm and crate feature e2e-encryption only.
pub fn first_key_value(&self) -> Option<(&K, &V)>where
K: Ord,
testing) and non-target_family=wasm and crate feature e2e-encryption only.Returns the first key-value pair in the map. The key in this pair is the minimum key in the map.
Examples
use std::collections::BTreeMap;
let mut map = BTreeMap::new();
assert_eq!(map.first_key_value(), None);
map.insert(1, "b");
map.insert(2, "a");
assert_eq!(map.first_key_value(), Some((&1, &"b")));1.66.0 · Sourcepub fn last_key_value(&self) -> Option<(&K, &V)>where
K: Ord,
Available on (crate features testing) and non-target_family=wasm and crate feature e2e-encryption only.
pub fn last_key_value(&self) -> Option<(&K, &V)>where
K: Ord,
testing) and non-target_family=wasm and crate feature e2e-encryption only.Returns the last key-value pair in the map. The key in this pair is the maximum key in the map.
Examples
use std::collections::BTreeMap;
let mut map = BTreeMap::new();
map.insert(1, "b");
map.insert(2, "a");
assert_eq!(map.last_key_value(), Some((&2, &"a")));1.0.0 · Sourcepub fn contains_key<Q>(&self, key: &Q) -> bool
Available on (crate features testing) and non-target_family=wasm and crate feature e2e-encryption only.
pub fn contains_key<Q>(&self, key: &Q) -> bool
testing) and non-target_family=wasm and crate feature e2e-encryption only.Returns true if the map contains a value for the specified key.
The key may be any borrowed form of the map’s key type, but the ordering on the borrowed form must match the ordering on the key type.
Examples
use std::collections::BTreeMap;
let mut map = BTreeMap::new();
map.insert(1, "a");
assert_eq!(map.contains_key(&1), true);
assert_eq!(map.contains_key(&2), false);1.17.0 · Sourcepub fn range<T, R>(&self, range: R) -> Range<'_, K, V>
Available on (crate features testing) and non-target_family=wasm and crate feature e2e-encryption only.
pub fn range<T, R>(&self, range: R) -> Range<'_, K, V>
testing) and non-target_family=wasm and crate feature e2e-encryption only.Constructs a double-ended iterator over a sub-range of elements in the map.
The simplest way is to use the range syntax min..max, thus range(min..max) will
yield elements from min (inclusive) to max (exclusive).
The range may also be entered as (Bound<T>, Bound<T>), so for example
range((Excluded(4), Included(10))) will yield a left-exclusive, right-inclusive
range from 4 to 10.
Panics
Panics if range start > end.
Panics if range start == end and both bounds are Excluded.
Examples
use std::collections::BTreeMap;
use std::ops::Bound::Included;
let mut map = BTreeMap::new();
map.insert(3, "a");
map.insert(5, "b");
map.insert(8, "c");
for (&key, &value) in map.range((Included(&4), Included(&8))) {
println!("{key}: {value}");
}
assert_eq!(Some((&5, &"b")), map.range(4..).next());1.0.0 · Sourcepub fn iter(&self) -> Iter<'_, K, V>
Available on (crate features testing) and non-target_family=wasm and crate feature e2e-encryption only.
pub fn iter(&self) -> Iter<'_, K, V>
testing) and non-target_family=wasm and crate feature e2e-encryption only.Gets an iterator over the entries of the map, sorted by key.
Examples
use std::collections::BTreeMap;
let mut map = BTreeMap::new();
map.insert(3, "c");
map.insert(2, "b");
map.insert(1, "a");
for (key, value) in map.iter() {
println!("{key}: {value}");
}
let (first_key, first_value) = map.iter().next().unwrap();
assert_eq!((*first_key, *first_value), (1, "a"));1.0.0 · Sourcepub fn keys(&self) -> Keys<'_, K, V>
Available on (crate features testing) and non-target_family=wasm and crate feature e2e-encryption only.
pub fn keys(&self) -> Keys<'_, K, V>
testing) and non-target_family=wasm and crate feature e2e-encryption only.Gets an iterator over the keys of the map, in sorted order.
Examples
use std::collections::BTreeMap;
let mut a = BTreeMap::new();
a.insert(2, "b");
a.insert(1, "a");
let keys: Vec<_> = a.keys().cloned().collect();
assert_eq!(keys, [1, 2]);1.0.0 · Sourcepub fn values(&self) -> Values<'_, K, V>
Available on (crate features testing) and non-target_family=wasm and crate feature e2e-encryption only.
pub fn values(&self) -> Values<'_, K, V>
testing) and non-target_family=wasm and crate feature e2e-encryption only.Gets an iterator over the values of the map, in order by key.
Examples
use std::collections::BTreeMap;
let mut a = BTreeMap::new();
a.insert(1, "hello");
a.insert(2, "goodbye");
let values: Vec<&str> = a.values().cloned().collect();
assert_eq!(values, ["hello", "goodbye"]);1.0.0 · Sourcepub fn len(&self) -> usize
Available on (crate features testing) and non-target_family=wasm and crate feature e2e-encryption only.
pub fn len(&self) -> usize
testing) and non-target_family=wasm and crate feature e2e-encryption only.Returns the number of elements in the map.
Examples
use std::collections::BTreeMap;
let mut a = BTreeMap::new();
assert_eq!(a.len(), 0);
a.insert(1, "a");
assert_eq!(a.len(), 1);1.0.0 · Sourcepub fn is_empty(&self) -> bool
Available on (crate features testing) and non-target_family=wasm and crate feature e2e-encryption only.
pub fn is_empty(&self) -> bool
testing) and non-target_family=wasm and crate feature e2e-encryption only.Returns true if the map contains no elements.
Examples
use std::collections::BTreeMap;
let mut a = BTreeMap::new();
assert!(a.is_empty());
a.insert(1, "a");
assert!(!a.is_empty());Sourcepub fn lower_bound<Q>(&self, bound: Bound<&Q>) -> Cursor<'_, K, V>
🔬This is a nightly-only experimental API. (btree_cursors)Available on (crate features testing) and non-target_family=wasm and crate feature e2e-encryption only.
pub fn lower_bound<Q>(&self, bound: Bound<&Q>) -> Cursor<'_, K, V>
btree_cursors)testing) and non-target_family=wasm and crate feature e2e-encryption only.Returns a Cursor pointing at the gap before the smallest key
greater than the given bound.
Passing Bound::Included(x) will return a cursor pointing to the
gap before the smallest key greater than or equal to x.
Passing Bound::Excluded(x) will return a cursor pointing to the
gap before the smallest key greater than x.
Passing Bound::Unbounded will return a cursor pointing to the
gap before the smallest key in the map.
Examples
#![feature(btree_cursors)]
use std::collections::BTreeMap;
use std::ops::Bound;
let map = BTreeMap::from([
(1, "a"),
(2, "b"),
(3, "c"),
(4, "d"),
]);
let cursor = map.lower_bound(Bound::Included(&2));
assert_eq!(cursor.peek_prev(), Some((&1, &"a")));
assert_eq!(cursor.peek_next(), Some((&2, &"b")));
let cursor = map.lower_bound(Bound::Excluded(&2));
assert_eq!(cursor.peek_prev(), Some((&2, &"b")));
assert_eq!(cursor.peek_next(), Some((&3, &"c")));
let cursor = map.lower_bound(Bound::Unbounded);
assert_eq!(cursor.peek_prev(), None);
assert_eq!(cursor.peek_next(), Some((&1, &"a")));Sourcepub fn upper_bound<Q>(&self, bound: Bound<&Q>) -> Cursor<'_, K, V>
🔬This is a nightly-only experimental API. (btree_cursors)Available on (crate features testing) and non-target_family=wasm and crate feature e2e-encryption only.
pub fn upper_bound<Q>(&self, bound: Bound<&Q>) -> Cursor<'_, K, V>
btree_cursors)testing) and non-target_family=wasm and crate feature e2e-encryption only.Returns a Cursor pointing at the gap after the greatest key
smaller than the given bound.
Passing Bound::Included(x) will return a cursor pointing to the
gap after the greatest key smaller than or equal to x.
Passing Bound::Excluded(x) will return a cursor pointing to the
gap after the greatest key smaller than x.
Passing Bound::Unbounded will return a cursor pointing to the
gap after the greatest key in the map.
Examples
#![feature(btree_cursors)]
use std::collections::BTreeMap;
use std::ops::Bound;
let map = BTreeMap::from([
(1, "a"),
(2, "b"),
(3, "c"),
(4, "d"),
]);
let cursor = map.upper_bound(Bound::Included(&3));
assert_eq!(cursor.peek_prev(), Some((&3, &"c")));
assert_eq!(cursor.peek_next(), Some((&4, &"d")));
let cursor = map.upper_bound(Bound::Excluded(&3));
assert_eq!(cursor.peek_prev(), Some((&2, &"b")));
assert_eq!(cursor.peek_next(), Some((&3, &"c")));
let cursor = map.upper_bound(Bound::Unbounded);
assert_eq!(cursor.peek_prev(), Some((&4, &"d")));
assert_eq!(cursor.peek_next(), None);Trait Implementations
impl Clone for ResultGroupMapsByGroupingKey
impl Clone for ResultGroupMapsByGroupingKey
fn clone(&self) -> ResultGroupMapsByGroupingKey
fn clone(&self) -> ResultGroupMapsByGroupingKey
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl Debug for ResultGroupMapsByGroupingKey
impl Debug for ResultGroupMapsByGroupingKey
impl Default for ResultGroupMapsByGroupingKey
impl Default for ResultGroupMapsByGroupingKey
fn default() -> ResultGroupMapsByGroupingKey
fn default() -> ResultGroupMapsByGroupingKey
impl Deref for ResultGroupMapsByGroupingKey
impl Deref for ResultGroupMapsByGroupingKey
type Target = BTreeMap<GroupingKey, ResultGroupMap>
type Target = BTreeMap<GroupingKey, ResultGroupMap>
fn deref(&self) -> &<ResultGroupMapsByGroupingKey as Deref>::Target
fn deref(&self) -> &<ResultGroupMapsByGroupingKey as Deref>::Target
impl<'de> Deserialize<'de> for ResultGroupMapsByGroupingKey
impl<'de> Deserialize<'de> for ResultGroupMapsByGroupingKey
fn deserialize<D>(
deserializer: D,
) -> Result<ResultGroupMapsByGroupingKey, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<ResultGroupMapsByGroupingKey, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
impl Extend<ResultGroupMap> for ResultGroupMapsByGroupingKey
impl Extend<ResultGroupMap> for ResultGroupMapsByGroupingKey
fn extend<T>(&mut self, iter: T)where
T: IntoIterator<Item = ResultGroupMap>,
fn extend<T>(&mut self, iter: T)where
T: IntoIterator<Item = ResultGroupMap>,
Sourcefn extend_one(&mut self, item: A)
fn extend_one(&mut self, item: A)
extend_one)Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
extend_one)impl FromIterator<ResultGroupMap> for ResultGroupMapsByGroupingKey
impl FromIterator<ResultGroupMap> for ResultGroupMapsByGroupingKey
fn from_iter<T>(iter: T) -> ResultGroupMapsByGroupingKeywhere
T: IntoIterator<Item = ResultGroupMap>,
fn from_iter<T>(iter: T) -> ResultGroupMapsByGroupingKeywhere
T: IntoIterator<Item = ResultGroupMap>,
impl IntoIterator for ResultGroupMapsByGroupingKey
impl IntoIterator for ResultGroupMapsByGroupingKey
type Item = ResultGroupMap
type Item = ResultGroupMap
type IntoIter = IntoValues<GroupingKey, ResultGroupMap>
type IntoIter = IntoValues<GroupingKey, ResultGroupMap>
fn into_iter(self) -> <ResultGroupMapsByGroupingKey as IntoIterator>::IntoIter
fn into_iter(self) -> <ResultGroupMapsByGroupingKey as IntoIterator>::IntoIter
impl Serialize for ResultGroupMapsByGroupingKey
impl Serialize for ResultGroupMapsByGroupingKey
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,